@@ -7,10 +7,12 @@ from .tikos import (Description,
                     AddExtractionFileStream,
                     AddExtractionFileStreams,
                     ProcessExtract,
+                    ProcessExtractFile,
                     GetExtract,
                     GetExtractDocs,
                     GetGraphStructure,
                     GenerateGraph,
                     GetGraph,
                     GetGraphRelationships,
-                    GetGraphRetrieval)
+                    GetGraphRetrieval,
+                    GetGraphRetrievalWithDS)
